@@ -51,6 +51,11 @@ class Range(Object):
             else:
                 setattr(receiver, key, None)
 
+    @method()
+    def setStep(self, receiver, context, m, value):
+        receiver.step = int(value.eval(context))
+        return receiver
+
     @method()
     def asList(self, receiver, context, m):
         return runtime.find("List").clone(list(receiver))
