@@ -107,16 +107,11 @@ def make_chain(messages, all=True):
             else:
                 value = make_chain(messages, all=False)
 
-            try:
-                assert key is not None
-                assert value is not None
-            except:
-                import pudb; pudb.set_trace()
             message = Message("set", args=[key, value])
         elif is_operator(messages[0]):
             message = messages.pop(0)
             if messages and not message.args:
-                if operators.get(message.name)[0] == 1:
+                if operators.get(message.name) == 1:
                     arg = messages.pop(0)
                     # Set the argument (a Message) previous attribute to the current message
                     arg.previous = message
