@@ -57,6 +57,11 @@ class String(Object):
         end = int(end.eval(context)) if end is not None else None
         return runtime.find("Number").clone(receiver.value.find(sub, start, end))
 
+    @method()
+    def format(self, receiver, context, m, *args):
+        args = [str(arg.eval(context)) for arg in args]
+        return receiver.clone(receiver.value.format(*args))
+
     @method()
     def join(self, receiver, context, m, xs):
         xs = xs.eval(context)
